package com.unitesk.reqcoverage.reqstracer;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.regex.Pattern;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;

public class ProjectProcessor {
	private Pattern pattern;
	private ErrorLog errorLog;
	private Set<String> extensions;
	private CoverageTracker tracker;
	
	public ProjectProcessor(Pattern regEx, Set<String> extensions, CoverageTracker tracker, ErrorLog log)
	{
		this.pattern = regEx;
		this.extensions = extensions;
		this.errorLog = log;
		this.tracker = tracker;
	}
	
	public void listFiles(IContainer i, List<IFile> result) throws CoreException {
		for (IResource res: i.members()) {
			if (res instanceof IContainer) {
				listFiles((IContainer) res, result);
			} else if (res instanceof IFile) {
				IFile file = (IFile) res;
				if (extensions.contains(file.getFileExtension()))
				{
					result.add(file);
				}
			}
		}
	}

	public void process(IProject project) throws CoreException 
	{
		ArrayList<IFile> files = new ArrayList<IFile>();
		listFiles(project, files);
		FileProcessor fproc = new FileProcessor(pattern, tracker, errorLog);
		for (IFile file : files)
		{
			String path = file.getLocation().toPortableString();
			fproc.process(path);
		}
	}
}
